@@ -17,8 +17,8 @@ class DialectShortcutsWindow(Gtk.ShortcutsWindow):
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
 
-        self.connect('show', self._on_show)
-
+    @Gtk.Template.Callback()
     def _on_show(self, _data):
-        self.translate_shortcut.set_visible(not Settings.get().live_translation)
-        self.translate_shortcut.set_property('accelerator', Settings.get().translate_accel)
+        """Called on self::show signal"""
+        self.translate_shortcut.props.visible = not Settings.get().live_translation
+        self.translate_shortcut.props.accelerator = Settings.get().translate_accel
